SignUpFieldsId enum

Inheritance
Available extensions

Values

email → const SignUpFieldsId
password → const SignUpFieldsId
repeat_password → const SignUpFieldsId
first_name → const SignUpFieldsId
last_name → const SignUpFieldsId
phone → const SignUpFieldsId
country → const SignUpFieldsId
city → const SignUpFieldsId
state → const SignUpFieldsId
zip → const SignUpFieldsId
address → const SignUpFieldsId
address2 → const SignUpFieldsId
undefined → const SignUpFieldsId

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toShortString() String

Available on SignUpFieldsId, provided by the SignUpFieldsIdToString extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SignUpFieldsId>
A constant List of the values in this enum, in order of their declaration.