SignUpRequest class
Constructors
-
SignUpRequest({required Map<
SignUpFieldsId, String> fields, required String recaptchaResponse, required String pkgName, required PlatformType platform, required String appSecret})
Properties
- appSecret ↔ String
-
getter/setter pair
-
fields
→ Map<
SignUpFieldsId, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pkgName ↔ String
-
getter/setter pair
- platform ↔ PlatformType
-
getter/setter pair
- recaptchaResponse ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited