ThingsboardClient class
Constructors
-
ThingsboardClient(String apiEndpoint, {TbStorage? storage, String? apiKey, UserLoadedCallback? onUserLoaded, MfaAuthCallback? onMfaAuth, MfaAuthCallback? onMfaForce, ErrorCallback? onError, LoadStartedCallback? onLoadStarted, LoadFinishedCallback? onLoadFinished, TbCompute? computeFunc, bool debugMode = false})
-
factory
Methods
-
changePassword(String currentPassword, String newPassword, {RequestConfig? requestConfig})
→ Future<void>
-
-
checkTwoFaVerificationCode(TwoFaProviderType providerType, String verificationCode, {RequestConfig? requestConfig})
→ Future<LoginResponse>
-
-
compute<Q, R>(TbComputeCallback<Q, R> callback, Q message)
→ Future<R>
-
-
delete<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken})
→ Future<Response<T>>
-
-
get<T>(String path, {Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken, ProgressCallback? onReceiveProgress})
→ Future<Response<T>>
-
-
getAdminService()
→ AdminService
-
-
getAlarmService()
→ AlarmService
-
-
getApiKeyService()
→ ApiKeyService
-
-
getAssetProfileService()
→ AssetProfileService
-
-
getAssetService()
→ AssetService
-
-
getAttributeService()
→ AttributeService
-
-
getAuditLogService()
→ AuditLogService
-
-
getAuthUser()
→ AuthUser?
-
-
getAuthUserFromJwt(String jwtToken)
→ AuthUser
-
-
getBlobEntityService()
→ BlobEntityService
-
-
getComponentDescriptorService()
→ ComponentDescriptorService
-
-
getConverterService()
→ ConverterService
-
-
getCustomerService()
→ CustomerService
-
-
-
getCustomTranslationService()
→ CustomTranslationService
-
-
getDashboardService()
→ DashboardService
-
-
getDeviceProfileService()
→ DeviceProfileService
-
-
getDeviceService()
→ DeviceService
-
-
getEdgeService()
→ EdgeService
-
-
getEntitiesVersionControlService()
→ EntitiesVersionControlService
-
-
getEntityGroupService()
→ EntityGroupService
-
-
getEntityQueryService()
→ EntityQueryService
-
-
getEntityRelationService()
→ EntityRelationService
-
-
getEntityViewService()
→ EntityViewService
-
-
getGroupPermissionService()
→ GroupPermissionService
-
-
getImageService()
→ ImageService
-
-
getIntegrationService()
→ IntegrationService
-
-
getJwtToken()
→ String?
-
-
getLoginDataBySecretKey({required String host, required String key, bool logging = false})
→ Future<LoginResponse>
-
-
getMobileService()
→ MobileService
-
-
getNotificationService()
→ NotificationsService
-
-
getOAuth2Service()
→ OAuth2Service
-
-
getOtaPackageService()
→ OtaPackageService
-
-
getOwnerService()
→ OwnerService
-
-
getPlatformVersion()
→ PlatformVersion?
-
-
getQueueService()
→ QueueService
-
-
getRefreshToken()
→ String?
-
-
getReportService()
→ ReportService
-
-
getResourceService()
→ ResourceService
-
-
getRoleService()
→ RoleService
-
-
getRuleChainService()
→ RuleChainService
-
-
getRuleEngineService()
→ RuleEngineService
-
-
getSchedulerEventService()
→ SchedulerEventService
-
-
getSelfRegistrationService()
→ SelfRegistrationService
-
-
getSignupService()
→ SignupService
-
-
getTelemetryService()
→ TelemetryService
-
-
getTenantProfileService()
→ TenantProfileService
-
-
getTenantService()
→ TenantService
-
-
getTwoFactorAuthService()
→ TwoFactorAuthService
-
-
getUserPermissionsService()
→ UserPermissionsService
-
-
getUserService()
→ UserService
-
-
getWhiteLabelingService()
→ WhiteLabelingService
-
-
getWidgetService()
→ WidgetService
-
-
init()
→ Future<void>
-
-
isApiKeyAuth()
→ bool
-
-
isAuthenticated()
→ bool
-
-
isCustomerUser()
→ bool
-
-
isJwtTokenValid()
→ bool
-
-
isMfaConfigurationToken()
→ bool
-
-
isPreVerificationToken()
→ bool
-
-
isSystemAdmin()
→ bool
-
-
isTenantAdmin()
→ bool
-
-
login(LoginRequest loginRequest, {RequestConfig? requestConfig})
→ Future<LoginResponse>
-
-
logout({RequestConfig? requestConfig, bool notifyUser = true})
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
post<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<T>>
-
-
put<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken})
→ Future<Response<T>>
-
-
refreshJwtToken({String? refreshToken, bool? notify, Dio? internalDio, bool interceptRefreshToken = false})
→ Future<void>
-
-
refreshTokenPending()
→ bool
-
-
reInit(String endpoint)
→ Future<void>
-
-
sendResetPasswordLink(String email, {RequestConfig? requestConfig})
→ Future<void>
-
-
setUserFromJwtToken(String? jwtToken, String? refreshToken, bool? notify)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited